@@ -10,6 +10,11 @@
     (asdf:load-system "cffi-tests"))
 
 (with-writable-locations
+    ;; The following is needed when executing compiled static programs
+    ;; (otherwise they won't find modules such as ASDF, or won't be able to
+    ;; compile them)
+    (setf (uiop:getenv "SBCL_HOME") "/usr/lib/sbcl"
+          (uiop:getenv "HOME") (uiop:getenv "AUTOPKGTEST_TMP"))
     ;; Can't use ASDF:TEST-SYSTEM, its return value is meaningless
     (unless (null (cffi-tests:run-all-cffi-tests))
         (uiop:quit 1)))
